summaryrefslogtreecommitdiffstats
path: root/src/detaileddialog.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/detaileddialog.h')
-rw-r--r--src/detaileddialog.h23
1 files changed, 12 insertions, 11 deletions
diff --git a/src/detaileddialog.h b/src/detaileddialog.h
index 3873030..59220cd 100644
--- a/src/detaileddialog.h
+++ b/src/detaileddialog.h
@@ -29,7 +29,7 @@
#include <kprogress.h>
// other QT headers:
-#include <qpixmap.h>
+#include <tqpixmap.h>
// own headers:
#include "hardware.h"
@@ -51,10 +51,11 @@
class detaileddialog: public detailed_Dialog {
Q_OBJECT
+ TQ_OBJECT
public:
//! default constructor
- detaileddialog(HardwareInfo *_hwinfo, QPixmap *_pixmap, Settings *_set, QWidget *parent = 0, const char *name = 0);
+ detaileddialog(HardwareInfo *_hwinfo, TQPixmap *_pixmap, Settings *_set, TQWidget *tqparent = 0, const char *name = 0);
//! default destructor
~detaileddialog();
@@ -85,29 +86,29 @@ private:
Settings *config;
//! pointer to the kpowersave class
- QPixmap *pixmap;
+ TQPixmap *pixmap;
//! the numbers of CPUs in the system
int numOfCPUs;
//! list of progressbars for battery information
/*!
* This QValueList with type KProgress contains the list
* of battery progress widgets. Each element represent
* one battery or batteryslot
*/
- QValueList<KProgress *> BatteryPBar;
+ TQValueList<KProgress *> BatteryPBar;
//! list of progressbars for CPU information
/*!
* This QValueList with type KProgress contains the list
* of CPU progress widgets. Each element represent one CPU.
*/
- QValueList<KProgress *> ProcessorPBar;
+ TQValueList<KProgress *> ProcessorPBar;
- //! QGridLayout for Battery progress widgets
- QGridLayout* BatteryGridLayout;
- //! QGridLayout for Processor progress widgets
- QGridLayout* ProcessorGridLayout;
+ //! TQGridLayout for Battery progress widgets
+ TQGridLayout* BatteryGridLayout;
+ //! TQGridLayout for Processor progress widgets
+ TQGridLayout* ProcessorGridLayout;
};
#endif
@@ -85,29 +86,29 @@ private:
//! list of progressbars for battery information
/*!
- * This QValueList with type KProgress contains the list
+ * This TQValueList with type KProgress contains the list
* of battery progress widgets. Each element represent
* one battery or batteryslot
@@ -85,29 +86,29 @@ private:
//! list of progressbars for CPU information
/*!
- * This QValueList with type KProgress contains the list
+ * This TQValueList with type KProgress contains the list
* of CPU progress widgets. Each element represent one CPU.
*/